@ECHO OFF
REM **************************************************************************
REM * Prepare the environment to run the Service Profiler.
REM **************************************************************************
REM * Wrightia, S.A. (c) 2006-2011
REM *
REM * Input parameters:
REM *    %1          - JVM_DIR      (The JVM installation directory)
REM *    %2          - IS_DIR       (The Integration Server installation directory)
REM *    %3          - IS_SERVICE   (Running As NT Service option)
REM *                   If running as service, no output can be sent to stdout
REM *                   under penalty of having the BATch terminate abruptly...
REM *                   ... and silently.
REM *    [%4]        - Optional.
REM *                   Contains VOID when the Core Libraries are being
REM *                   intentionally prevented from loading.
REM *                   The call is made on this situation only to log the
REM *                   occurence.
REM *
REM * Results:
REM *    The script creates 3 (three) environment variables to be used by the
REM *    caller:
REM *
REM *    ISSPROF_JVM - Options to be added to the JVM command line
REM *    ISSPROF_CP  - Path entries to the added to the -cp (CLASSPATH) of the
REM *                  JVM command line
REM *    ISSPROF_LIB - Path to the folder/directory where the needed DLLs are
REM *                  installed. This must be addded to the PATH variable,
REM *                  or other setting that can be used by the runtime to
REM *                  locate and use DLLs.
REM *
REM **************************************************************************

SET ARG_1=%~1
SET ARG_2=%~2

IF "%ARG_1%" == "/?" GOTO USAGE_INFO
IF "%ARG_1%" == "/h" GOTO USAGE_INFO
IF "%ARG_1%" == "/H" GOTO USAGE_INFO
IF "%ARG_1%" == "?"  GOTO USAGE_INFO

IF "%ARG_2%" == "" (
   ECHO.
   ECHO ERROR: Mandatory arguments are missing.
   Call :USAGE_INFO
   GOTO :ABORT_DIRECT
)

IF "1%3" == "1-service" (
   SET IS_SERVICE=Y
) ELSE (
   SET IS_SERVICE=N
)

REM // The "issprof_rsc" profiler resources directory
SET XISSPROF_RESDIR=%ARG_2%\serviceprofiler

REM // Log file name
IF NOT EXIST "%XISSPROF_RESDIR%\logs"    MD "%XISSPROF_RESDIR%\logs"
SET XISSPROF_LOGFILENAME="%XISSPROF_RESDIR%\logs\issprof.log"

Call :LOG_BEGIN "Preparing for Wrightia Service Profiler..."
IF "1-%4" == "1-VOID" (
   Call :LOG "INFO: Core libraries intentionally prevented from loading"
   GOTO ABORT_DIRECT
)

REM // Directory to use for storing the generated ClassLoader
SET XISSPROF_TMPCLDIR=%XISSPROF_RESDIR%\tmp
IF NOT EXIST "%XISSPROF_TMPCLDIR%"       MD "%XISSPROF_TMPCLDIR%"

REM // Native lib directory
SET ISSPROF_LIB=%XISSPROF_RESDIR%\lib

REM // The interceptor classes ClassPath element
SET XISSPROF_INTCP=%ISSPROF_LIB%\wia-profiler-intc-is-11.jar

REM // Path to "java.exe"
SET XISSPROF_JAVA="%ARG_1%\bin\java.exe"

IF NOT EXIST %XISSPROF_JAVA% (
   Call :LOG "ERROR: java.exe not found. Java is NOT properly installed at:"
   Call :LOG "       '%ARG_1%'"
   GOTO :ABORT
)

Call :LOG "INFO: Java Directory = '%ARG_1%'"


SET XISSPROF_TMPCLJAR=%XISSPROF_TMPCLDIR%\issprof-cloader.jar
Call :LOG "INFO: Removing any previously generated ClassLoader..."
DEL "%XISSPROF_TMPCLJAR%" 2> nul

REM // Generating new ClassLoader
Call :LOG "INFO: Generating new ClassLoader (%XISSPROF_TMPCLJAR%)..."
%XISSPROF_JAVA% -Dwm.server.init="%ARG_2%\bin\ini.cnf" -cp "%XISSPROF_INTCP%" com.wrightia.wm.is.profiler.intercept.IssprofJarBuilder "%XISSPROF_TMPCLJAR%"

IF NOT "%ERRORLEVEL%"=="0" (
   Call :LOG "ERROR: Error generating ClassLoader (%XISSPROF_TMPCLJAR%)"
   GOTO :ABORT
)

Call :LOG "INFO: ClassLoader generated successfuly"

REM // JVM Boot (-X...) arguments
SET XISSPROF_ARGX=-Xbootclasspath/p:"%XISSPROF_TMPCLJAR%;%XISSPROF_INTCP%"
SET XISSPROF_ARGX_WIN=-Xbootclasspath/p:\"%XISSPROF_TMPCLJAR%;%XISSPROF_INTCP%\"

REM // Additional profiling properties can be set here
SET XISSPROF_PROPS=

REM // Set output parameters
SET ISSPROF_CP=
SET ISSPROF_JVM=%XISSPROF_ARGX% %XISSPROF_PROPS%
SET ISSPROF_JVM_WIN=%XISSPROF_ARGX_WIN% %XISSPROF_PROPS%

REM // Generating IS profile wrapper configuration
SET XISSPROF_WRPCONF_FILENAME=wrapper.conf
SET XISSPROF_WRPCONF_SOURCE=%ARG_2%\..\profiles\IS\configuration\%XISSPROF_WRPCONF_FILENAME%
SET XISSPROF_WRPCONF_TARGET=%XISSPROF_RESDIR%\var\%XISSPROF_WRPCONF_FILENAME%

If Not Exist "%XISSPROF_WRPCONF_SOURCE%" GoTo :WRAPPER_DONE
Find "%XISSPROF_WRPCONF_TARGET%" "%XISSPROF_WRPCONF_SOURCE%" > nul
If "%ERRORLEVEL%"=="0" GoTo :WRAPPER_DONE

Call :LOG "INFO: Generating IS profile wrapper configuration (%XISSPROF_WRPCONF_TARGET%)..."
%XISSPROF_JAVA% -Dwm.server.init="%ARG_2%\bin\ini.cnf" -cp "%XISSPROF_INTCP%" com.wrightia.wm.is.config.WrapperBuilder "%ISSPROF_LIB%" "%ISSPROF_JVM_WIN%" "%XISSPROF_WRPCONF_SOURCE%" "%XISSPROF_WRPCONF_TARGET%"
IF NOT "%ERRORLEVEL%"=="0" (
   Call :LOG "ERROR: Error generating IS profile wrapper configuration (%XISSPROF_WRPCONF_TARGET%)"
   GOTO :ABORT
)
Call :LOG "INFO: IS profile wrapper configuration file generated successfuly"

Copy "%XISSPROF_WRPCONF_SOURCE%" "%XISSPROF_WRPCONF_SOURCE%.beforeissprof"
Echo.                                                                      >> "%XISSPROF_WRPCONF_SOURCE%"
Echo #******************************************************************** >> "%XISSPROF_WRPCONF_SOURCE%"
Echo # Wrightia Service Profiler configuration file                        >> "%XISSPROF_WRPCONF_SOURCE%"
Echo #******************************************************************** >> "%XISSPROF_WRPCONF_SOURCE%"
Echo #include %XISSPROF_WRPCONF_TARGET%                                    >> "%XISSPROF_WRPCONF_SOURCE%"

:WRAPPER_DONE

REM // Cleanup...
SET XISSPROF_WRPCONF_FILENAME=
SET XISSPROF_WRPCONF_SOURCE=
SET XISSPROF_WRPCONF_TARGET=

REM // Cleanup...
SET XISSPROF_JAVA=
SET XISSPROF_INTCP=
SET XISSPROF_TMPCLJAR=
SET XISSPROF_ARGX=
SET XISSPROF_ARGX_WIN=
SET ISSPROF_JVM_WIN=
SET XISSPROF_PROPS=

GOTO RETURN


:USAGE_INFO
   ECHO.
   ECHO Wrightia Service Profiler (c) 2006-2011
   ECHO.
   ECHO Usage:
   ECHO     prepare.bat JAVA_DIR IS_DIR
   ECHO where:
   ECHO     JAVA_DIR    - Java installation directory
   ECHO     IS_DIR      - Integration Server installation directory
   ECHO.
   REM // Return with ERRORLEVEL!=0 when AOP was NOT correctly prepared.
   EXIT /B -1


:RETURN
   Call :SHOW_RESULTS
   EXIT /B 0


:SHOW_RESULTS
   IF "%IS_SERVICE%" == "N" (
      ECHO.
      ECHO Script Results
      ECHO ==================================
      ECHO    ISSPROF_LIB = '%ISSPROF_LIB%'
      ECHO    ISSPROF_CP  = '%ISSPROF_CP%'
      ECHO    ISSPROF_JVM = '%ISSPROF_JVM%'
      ECHO.
   )
   ECHO.                                     >> %XISSPROF_LOGFILENAME%
   ECHO Script Results                       >> %XISSPROF_LOGFILENAME%
   ECHO ==================================   >> %XISSPROF_LOGFILENAME%
   ECHO    ISSPROF_LIB = '%ISSPROF_LIB%'     >> %XISSPROF_LOGFILENAME%
   ECHO    ISSPROF_CP  = '%ISSPROF_CP%'      >> %XISSPROF_LOGFILENAME%
   ECHO    ISSPROF_JVM = '%ISSPROF_JVM%'     >> %XISSPROF_LOGFILENAME%
   ECHO.                                     >> %XISSPROF_LOGFILENAME%
   EXIT /B 0


:ABORT
   Call :LOG "."
   Call :LOG "The preparation for Wrightia Service Profiler has FAILED."
   IF "%IS_SERVICE%" == "N" (
      ECHO.
      ECHO For further diagnostics, please check the generated log file:
      ECHO     %XISSPROF_LOGFILENAME%
      ECHO.
   )


:ABORT_DIRECT
   EXIT /B -1


:LOG
   REM // Writes a new message both for the console and the log file
   IF "%IS_SERVICE%" == "N"  ECHO %~1

   ECHO %~1 >> %XISSPROF_LOGFILENAME%
   exit /b 0


:LOG_BEGIN
   REM // (re)initializes the log file
   IF "%IS_SERVICE%" == "N"  ECHO %~1

   ECHO %~1 > %XISSPROF_LOGFILENAME%
   ECHO ========================================================================= >> %XISSPROF_LOGFILENAME%
   DATE /T >> %XISSPROF_LOGFILENAME%
   TIME /T >> %XISSPROF_LOGFILENAME%
   ECHO ========================================================================= >> %XISSPROF_LOGFILENAME%
   exit /b 0

