#!/bin/ksh
# *****************************************************************************
#  Patch #2 for Service Profiler v1.2.2
# *****************************************************************************
#  Wrightia, S.A. (c) 2012
#
#  Purpose:
#     1. Replace all native libraries
#     2. Replace all server and static JAR libraries
#
#  Input parameters:
#     $1          : IS_DIR  (The Integration Server installation directory)
#
#  Results:
#     1. Upgrades v1.2.2 to v1.3.
#
#  Exit codes:
#     0  - OK
#
# *****************************************************************************

log() {
   echo "[$1] [`date +%C%y-%m-%d\ %H:%M:%S`] $2" >> updates.log
}

logError() {
   log "ERROR" "$1"
}

logWarning() {
   log "WARNING" "$1"
}

logInfo() {
   log "INFO" "$1"
}

#--< MAIN	>------------------------------------------------------------------
if [ -d ../error ]; then
   if [ ! -z "`ls ../error/ | sort | grep .upd.sh`" ] ; then
      logWarning "Previous updates with error were found: '$0 $*' skipped."
      exit 100
   fi
else
   mkdir ../error
fi

xISHome=$1
xTargetHome=$xISHome/serviceprofiler
if [ -d "$xTargetHome" ] ; then
   # replace previous installation on server folder
   rm -rf "$xTargetHome"
   cp -r ../../serviceprofiler "${xISHome}/"
   xEL=$?
   if [ $xEL -eq 0 ]; then
      logInfo "All dynamic libraries copied successfully."
      mv -f ./v1-2-2_patch2.core.jar ../../../code/jars/static/wia-profiler-core-11.jar
      xEL=$?
      if [ $xEL -eq 0 ]; then
         logInfo "wia-profiler-core-11.jar moved successfully."
         mv -f ./v1-2-2_patch2.ispkg.jar ../../../code/jars/wia-profiler-ispkg-11.jar
         xEL=$?
         if [ $xEL -eq 0 ]; then
            logInfo "wia-profiler-ispkg-11.jar moved successfully."
            logInfo "Update '$0' successful."
         else
            logError "Error '$xEL' copying libraries."
            exit $xEL
         fi
      else
         logError "Error '$xEL' copying libraries."
         exit $xEL
      fi
   else
      logError "Error '$xEL' copying libraries."
      exit $xEL
   fi
else
   logWarning "Directory '$xISHome/serviceprofiler' was not found: '$0 $*' not applied."
fi

